Client

Struct Client 

pub struct Client { /* private fields */ }
A client for sending commands to a specific LaserCube device.

Implementations

Source

impl Client

pub async fn new( bind_ip: IpAddr, target_ip: Ipv4Addr, ) -> Result<Self, CommandError>

Create a new Client from a single target device IP (non-broadcast).

Returns a new Client or an error if the socket couldn’t be created.

Example
use futures::StreamExt;

#[tokio::main]
async fn main() -> Result<(), Box<dyn std::error::Error>> {
    // First discover devices
    let bind_ip = [0, 0, 0, 0].into();
    let target_ip = [255, 255, 255, 255].into();
    let mut devices = lasercube::discover::devices(bind_ip, target_ip).await?;

    // Connect to the first device found
    if let Some(device_info) = devices.next().await {
        let client = lasercube::Client::new(bind_ip, device_info.header.ip_addr).await?;

        // Now you can send commands to the device
        let buffer_free = client.get_buffer_free().await?;
        println!("Buffer free: {buffer_free}");

        // Enable output
        client.set_output(true).await?;
    }

    Ok(())
}
pub async fn send_command( &self, command: Command, ) -> Result<Response, CommandError>

Send a command to the LaserCube and wait for a response.

This method will await until a response is received.

Returns the parsed response, or an error in the case that an I/O issue occurred or an unexpected response was received.

pub async fn get_buffer_free(&self) -> Result<u16, CommandError>

Get the amount of free space in the device’s buffer.

Returns the number of free points in the buffer, or an error.

pub async fn set_output(&self, enable: bool) -> Result<(), CommandError>

Enable or disable laser output.

pub async fn enable_buffer_size_response( &self, enable: bool, ) -> Result<(), CommandError>

Enable or disable buffer size responses on data packets.